'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.setSourcesToVideo = exports.setSourcesToImg = undefined;

var _setSourceType = require('./setSourceType');

var getSources = function getSources($el) {
  return {
    sm: $el.dataset.sourceMobile,
    md: $el.dataset.sourceTablet,
    lg: $el.dataset.sourceDesktop,
    xl: $el.dataset.sourceXl
  };
};

var setMedia = function setMedia(breakpoints, sources) {
  return {
    sm: 'screen and (max-device-width: ' + breakpoints.sm + 'px)',
    md: '(min-device-width: ' + (breakpoints.sm + 1) + 'px) and (max-device-width: ' + breakpoints.md + 'px)',
    lg: sources.xl ? '(min-device-width: ' + (breakpoints.md + 1) + 'px) and (max-device-width: ' + breakpoints.lg + 'px)' : '(min-device-width: ' + (breakpoints.md + 1) + 'px)',
    xl: '(min-device-width: ' + (breakpoints.lg + 1) + 'px)'
  };
};

var setSourcesToImg = exports.setSourcesToImg = function setSourcesToImg($el, breakpoints) {
  var $picture = $el.parentNode;
  if ($picture.tagName.toLowerCase() !== 'picture') {
    $picture = document.createElement('picture');
    $el.after($picture);
    $picture.append($el);
  }

  var sources = getSources($el);
  var media = setMedia(breakpoints, sources);

  Object.keys(sources).forEach(function (key) {
    if (!sources[key]) return;

    var $source = document.createElement('source');
    $source.setAttribute('srcset', sources[key]);
    $source.setAttribute('media', media[key]);
    var type = (0, _setSourceType.setSourceType)(sources[key]);
    type && $source.setAttribute('type', type);

    $el.before($source);
  });
};

var setSourcesToVideo = exports.setSourcesToVideo = function setSourcesToVideo($el, breakpoints) {
  var sources = getSources($el);
  var media = setMedia(breakpoints, sources);

  Object.keys(sources).forEach(function (key) {
    if (!sources[key]) return;
    var $source = document.createElement('source');
    $source.setAttribute('srcset', sources[key]);
    $source.setAttribute('media', media[key]);
    $el.append($source);
  });
};